==> haskell-validation-selective-0.2.0.0-129.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-KILlRG2ti48J3BGw7UAm1V
key:                  validation-selective-0.2.0.0-KILlRG2ti48J3BGw7UAm1V
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  f10bb6e07b586a6d05aeff839bc930b8
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-KILlRG2ti48J3BGw7UAm1V
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    selective-0.7.0.1-FDsuzXmv4XNux7rTsGlbt

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validation-selective-0.2.0.0-130-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-3ecfd9K5DIA1eGBn8v2bT
key:                  validation-selective-0.2.0.0-3ecfd9K5DIA1eGBn8v2bT
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  d5196237f09d19845831c5e5b4b71821
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-3ecfd9K5DIA1eGBn8v2bT
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    selective-0.7.0.1-6ggLWum3GBuLRCSvIchXMz

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
